@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
 """
 @author:XuMing(xuming624@qq.com)
-@description: refer https://github.com/ThilinaRajapakse/simpletransformers
+@description:
 """
 
 from textgen.config.model_args import LanguageModelingArgs
 from textgen.language_modeling.language_modeling_model import LanguageModelingModel
+from textgen.config.model_args import SongNetArgs
+from textgen.language_modeling.songnet_model import SongNetModel
+from textgen.language_modeling.songnet_utils import SongNetTokenizer
