@@ -112,6 +112,7 @@ class T5Model:
                 )
         else:
             self.device = "cpu"
+        logger.debug(f"Device: {self.device}")
 
         self.results = {}
 
@@ -191,10 +192,6 @@ class T5Model:
 
         if args:
             self.args.update_from_dict(args)
-
-        # if self.args.silent:
-        #     show_running_loss = False
-
         if self.args.evaluate_during_training and eval_data is None:
             raise ValueError(
                 "evaluate_during_training is enabled but eval_data is not specified."
@@ -741,9 +738,6 @@ class T5Model:
                 output_dir, "checkpoint-{}-epoch-{}".format(global_step, epoch_number)
             )
 
-            if args.save_model_every_epoch or args.evaluate_during_training:
-                os.makedirs(output_dir_current, exist_ok=True)
-
             if args.save_model_every_epoch:
                 self.save_model(output_dir_current, optimizer, scheduler, model=model)
 
@@ -1001,12 +995,13 @@ class T5Model:
 
         return results
 
-    def predict(self, to_predict):
+    def predict(self, to_predict, split_on_space=False):
         """
         Performs predictions on a list of text.
 
         Args:
             to_predict: A python list of text (str) to be sent to the model for prediction. Note that the prefix should be prepended to the text.
+            split_on_space (optional): If True, input is english string, if False, input is chinese string.
 
         Returns:
             preds: A python list of the generated sequences.
@@ -1079,7 +1074,8 @@ class T5Model:
                 )
                 for output_id in all_outputs
             ]
-
+        if not split_on_space:
+            outputs = [''.join(gen_text.split(' ')) for gen_text in outputs]
         if self.args.num_return_sequences > 1:
             return [
                 outputs[i: i + self.args.num_return_sequences]
